@@ -36,7 +36,7 @@ if [ "x$IMAGE" = "x" ]; then
   
   DEF_COVER="$2"/default"-${4}.png"
 
-  convert \( $CONF_FIR/../Icons/common/audio-default.svg -resize $4x$4 \) -append $DEF_COVER 2> /dev/null;
+  convert -resize $4x$4 -depth 8 -background transparent $CONF_FIR/../Icons/common/cover-audio.png $DEF_COVER 2> /dev/null;
   
   if [ -s $DEF_COVER ]; then
     echo "$2"/default"-${4}.png"
@@ -53,7 +53,7 @@ else
   fi
 
   if [ ! -f "$2"/"$IFILE" ]; then
-      convert \( "$IMAGE" -resize $4x$4 \) -append "$2"/"$IFILE" 2> /dev/null;
+      convert -resize $4x$4 -depth 8 -background transparent "$IMAGE" "$2"/"$IFILE" 2> /dev/null;
   fi;
 
   if [ -s "$2"/"$IFILE" ]; then
