@@ -1,10 +1,10 @@
-#!/bin/bash
+#!/bin/sh
 
 #
-# Must be called from anyremote configuration file as $(CfgDir)/Utils/pulse-audio-ctl.sh up|down|mute|set <sink name> [<volume>]
+# Must be called from anyremote configuration file as $(CfgDir)/Utils/pulse-audio-ctl.sh up|down|mute|set|get <sink name> [<volume>]
 #
 
-if [ "x$1" == "xup" ]; then
+if [ "x$1" = "xup" ]; then
   HEXVOL=`pacmd dump | grep "set-sink-volume $2" | cut -d " " -f 3`
   VOL=`printf "%d" $HEXVOL`
   # about 5%
@@ -16,7 +16,7 @@ if [ "x$1" == "xup" ]; then
   pactl set-sink-volume $2 $NEWVOL 
 fi
 
-if [ "x$1" == "xdown" ]; then
+if [ "x$1" = "xdown" ]; then
   HEXVOL=`pacmd dump | grep "set-sink-volume $2" | cut -d " " -f 3`
   VOL=`printf "%d" $HEXVOL`
   # about 5%
@@ -28,7 +28,7 @@ if [ "x$1" == "xdown" ]; then
   pactl set-sink-volume $2 $NEWVOL 
 fi
 
-if [ "x$1" == "xmute" ]; then
+if [ "x$1" = "xmute" ]; then
   A=`pacmd dump | grep "set-sink-mute $2" | cut -d " " -f 3`
   if [ $A = "no" ]
   then
@@ -38,7 +38,7 @@ if [ "x$1" == "xmute" ]; then
   fi
 fi 
 
-if [ "x$1" == "xset" ]; then
+if [ "x$1" = "xset" ]; then
   VOL=`echo $3|tr -d '%'`
   NEWVOL=`echo "$VOL*65536/100"|bc`
   if [ $(($NEWVOL)) -lt $((0x00000)) ]
@@ -52,7 +52,7 @@ if [ "x$1" == "xset" ]; then
   pactl set-sink-volume $2 $NEWVOL;
 fi; 
 
-if [ "x$1" == "xget" ]; then
+if [ "x$1" = "xget" ]; then
   HEXVOL=`pacmd dump | grep "set-sink-volume $2" | cut -d " " -f 3`
   VOL65=`printf "%d" $HEXVOL`
   VOL=`echo "$VOL65*100/65536"|bc`
