@@ -25,20 +25,20 @@ if [ "x$2" = "xset" ] && [ "x$4" = "x" ]; then
 fi;
 
 if [ "x$2" = "xset" ]; then
-    grep -v $3 $1/$REGISTRY > $1/$REGISTRY.tmp
+    grep -v "^$3=" $1/$REGISTRY > $1/$REGISTRY.tmp
     mv $1/$REGISTRY.tmp $1/$REGISTRY
     echo "$3=$4" >> $1/$REGISTRY
     exit 0;
 fi;
 
 if [ "x$2" = "xget" ]; then
-    VALUE=`grep $3 $1/$REGISTRY|cut -f 2 -d '=' 2> /dev/null`
+    VALUE=`grep "^$3=" $1/$REGISTRY|cut -f 2 -d '=' 2> /dev/null`
     echo $VALUE
     exit 0;
 fi;
 
 if [ "x$2" = "xrm" ]; then
-    grep -v $3 $1/$REGISTRY > $1/$REGISTRY.tmp
+    grep -v "^$3=" $1/$REGISTRY > $1/$REGISTRY.tmp
     mv $1/$REGISTRY.tmp $1/$REGISTRY
     exit 0;
 fi;
