@@ -42,19 +42,21 @@ if [ "x$IS_RUN" = "x" ]; then
 
 else
   
-  WIN_ID=`wmctrl -l -p|grep $IS_RUN|cut -d ' ' -f 1`
+  if [ "x$WMCTRL" != "x" ]; then
+    WIN_ID=`wmctrl -l -p|grep $IS_RUN|cut -d ' ' -f 1`
 
-  if [ "x$WIN_ID" = "x" ]; then
+    if [ "x$WIN_ID" = "x" ]; then
 
-    # can not find app window, start it again
-    if [ "x$RUN" = "xYES" ]; then
-      killall $APP
-      $APP 2> /dev/null &
+      # can not find app window, start it again
+      if [ "x$RUN" = "xYES" ]; then
+        killall $APP
+        $APP 2> /dev/null &
+      fi;
+
+      exit 0;
     fi;
-    
-    exit 0;
+
+    wmctrl -i -a $WIN_ID
   fi;
 
-  wmctrl -i -a $WIN_ID
-
 fi; 
