@@ -16,7 +16,7 @@ fi
 
 
 PROVIDER="wttr.in/"
-OPTIONS="'?lang='"$LOCALIZATION"'\&'"
+OPTIONS="?lang="$LOCALIZATION"'\&'"
 
 if [ "x$1" = "x-current" ]; then
   curl -m 5 -s $PROVIDER$2${OPTIONS}0nQT
