@@ -2,11 +2,11 @@
 // anyRemote
 // a wi-fi or bluetooth remote for your PC.
 //
-// Copyright (C) 2012-2014 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2016 Mikhail Fedotov <anyremote@mail.ru>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
+// the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -16,7 +16,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 //
 
 #include <stdlib.h>
@@ -58,7 +58,7 @@ void manageAlarms(int mode)
     SingleList* list = _alarmList;
     while (list) {
 
-	type_alarm * v = (type_alarm *) list->data;
+        type_alarm * v = (type_alarm *) list->data;
 
         // If file exists
         int fs = stat(v->file, &buf);
@@ -69,6 +69,7 @@ void manageAlarms(int mode)
                 INFO2("[ML]: Alarm %s fired", v->macro);
 
                 eMessage* em = (eMessage*) malloc(sizeof(eMessage));
+                em->peer  = 0;
                 em->type  = EM_ALARM;
                 em->value = strdup(v->macro);
 
@@ -139,18 +140,16 @@ static void checkKeepalive()
     
     if (!_keepaliveFlag) {
 	
-	_keepaliveTimeout = 0;
-	
-	DEBUG2("[ML]: no keepalive message, drop connection");
-        
-	// drop connection
-	dMessage* dm = (dMessage*) malloc(sizeof(dMessage));
-	dm->size  = 0;
-	dm->value = (void*) NULL;
-	dm->type  = DM_EVENT_DISCONNECT;
-	dm->file  = NULL;
+	    _keepaliveTimeout = 0;
 
-	sendToDispatcher(dm);
+	    DEBUG2("[ML]: no keepalive message, drop connection");
+
+	    // drop connection
+	    dMessage* dm = allocDMessage();
+	    dm->type     = DM_EVENT;
+        dm->subtype  = ID_EVENT_DISCONNECT;
+
+	    sendToDispatcher(dm);
     }
    _keepaliveFlag = BOOL_NO; 
 }
@@ -161,25 +160,25 @@ void keepaliveTest()
     if (_keepaliveTimeout > 0) {
 
         time_t now = time(NULL);   
-	double st = difftime(now, _keepaliveSendTime);
-	double dt = difftime(now, _keepaliveDropTime);
+        double st = difftime(now, _keepaliveSendTime);
+        double dt = difftime(now, _keepaliveDropTime);
  
     	if (dt > _keepaliveTimeout * 2) { // about (_keepaliveTimeout * 2) seconds
     	    checkKeepalive();
-	    time(&_keepaliveDropTime);
+            time(&_keepaliveDropTime);
     	}
 	
     	if (st > _keepaliveTimeout) {
 
             DEBUG2("[ML]: send keepalive message");
 	    
-	    dMessage* dm = (dMessage*) malloc(sizeof(dMessage));
-	    dm->value = strdup("Get(ping);");
-	    dm->size  = strlen(dm->value);
-	    dm->file  = NULL;
-	    dm->type  = DM_SET;
-
-	    sendToDispatcher(dm);
+	        dMessage* dm = allocDMessage();
+	        dm->value    = strdup("Get(ping);");
+	        dm->size     = strlen(dm->value);
+	        dm->type     = DM_GET;
+            dm->subtype  = ID_GET_PING;
+            
+	        sendToDispatcher(dm);
 	    
     	    time(&_keepaliveSendTime);
     	}
@@ -199,14 +198,14 @@ void addKeepalive(const char* tmout)
     if (tmout && atoi(tmout) > 0) {
     
         _keepaliveTimeout = atoi(tmout);
-	DEBUG2("[ML]: keepalive timeout set to %d seconds", _keepaliveTimeout);
+        DEBUG2("[ML]: keepalive timeout set to %d seconds", _keepaliveTimeout);
 	
-	time(&_keepaliveSendTime);
-	time(&_keepaliveDropTime);
+       time(&_keepaliveSendTime);
+       time(&_keepaliveDropTime);
 	
     } else {
         _keepaliveTimeout = -1;
-	DEBUG2("[ML]: drop keepalive check");
+        DEBUG2("[ML]: drop keepalive check");
     }
 }
 
