@@ -1472,7 +1472,7 @@ int macroCmd(int subtype, const char *descr, const char *exec, cmdParams* params
     type_key *k = findItem(descr, &found, NULL);
 
     if (k && found == FLAG_EXACT) {
-        ret = handleCmdByKey(PEER_ANY,k, params);
+        ret = handleCmdByKey(PEER_ANY, k, params);
         DEBUG2("[EX]: Return code from macroCmd -> handleCmdByKey() is %d",ret);
     }
 
@@ -1561,7 +1561,9 @@ static int processOneCommand(cmdItem* ci, cmdParams* p)
     const char* descr = (sDescr ? sDescr->str : NULL);
     const char* exec  = (sExec  ? sExec->str  : NULL);
 
-    ret = (*_cmdHooks[ci->type].hook)(ci->subtype, descr, exec, p);
+    if (_cmdHooks[ci->type].hook) {
+        ret = (*_cmdHooks[ci->type].hook)(ci->subtype, descr, exec, p);
+    }
 
     if (sDescr) {
         stringFree(sDescr, BOOL_YES);
@@ -1578,22 +1580,24 @@ static int processCommands(SingleList* commands, cmdParams* p)
     SingleList* list = commands;
     while (list) {
 
-    cmdItem * item = (cmdItem *) list->data;
+        cmdItem* item = (cmdItem *) list->data;
 
-        /*if (item->descr == NULL) {
-            sprintf(tmp, "Process next command NULL parameters");
-        } else {
-            sprintf(tmp, "Process next command %s",item->descr);
-        }
-        logger(L_DBG, tmp);
-        */
-        
-        int ret = processOneCommand(item, p);
-    
-        if (ret != EXIT_OK) {
-            if (ret == EXIT_STOP) {
-                logger(L_DBG, "[EX]: Stop execution on current command sequence");
-                return EXIT_STOP;     // just stop execution of command sequence
+        if (item != NULL) {
+            /*if (item->descr == NULL) {
+                sprintf(tmp, "Process next command NULL parameters");
+            } else {
+                sprintf(tmp, "Process next command %s",item->descr);
+            }
+            logger(L_DBG, tmp);
+            */
+
+            int ret = processOneCommand(item, p);
+
+            if (ret != EXIT_OK) {
+                if (ret == EXIT_STOP) {
+                    logger(L_DBG, "[EX]: Stop execution on current command sequence");
+                    return EXIT_STOP;     // just stop execution of command sequence
+                }
             }
         }
 
