@@ -315,7 +315,7 @@ static int processOutputData()
             !haveConnectionless() &&
                 !(dm->type == DM_EVENT)) { // can process these even if no connection
 
-            logger(L_DBG, "[DS]: No connection. Skip event");
+            //logger(L_DBG, "[DS]: No connection. Skip event");
 
         } else {
             
