@@ -2,11 +2,11 @@
 // anyRemote
 // a wi-fi or bluetooth remote for your PC.
 //
-// Copyright (C) 2011-2014 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2016 Mikhail Fedotov <anyremote@mail.ru>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
+// the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -16,7 +16,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 //
 
 #include <ctype.h>
@@ -375,7 +375,7 @@ string_t* renderFormHead(int form, const char* caption, const char* fg, const ch
 
 string_t* renderCtrlHTMLForm(string_t* no_use, int port)
 {
-    INFO2("[WS]: renderCtrlHTMLForm");
+    INFO2("[WS]: renderCtrlHTMLForm %d", bottomlineSkin());
 
     string_t* fontSpec = fontHTML(cfFont());
     
@@ -425,6 +425,7 @@ string_t* renderCtrlHTMLForm(string_t* no_use, int port)
 
         
         const char* icon = cfIcon(i);
+        const char* hint = cfHint(i);
 	
 	    INFO2("[WS]: renderControlForm %d %s", i, (icon? icon : "NULL"));
 	
@@ -437,7 +438,13 @@ string_t* renderCtrlHTMLForm(string_t* no_use, int port)
         if (!icon || strcmp(icon,"none") == 0) {
 
             //<button <img src="XX" alt="" style="vertical-align: middle">label_empty</button>
-            stringAppend(page, "<button <img src=\"transparent.png\" border=\"0\" alt=\"\" style=\"vertical-align: middle\"></button>");
+            stringAppend(page, "<button <img src=\"transparent.png\" border=\"0\" alt=\"");
+            if (hint && strlen(hint) > 0) {
+                stringAppend(page, hint);
+                stringAppend(page, "\" title=\"");
+                stringAppend(page, hint);
+            }
+            stringAppend(page, "\" style=\"vertical-align: middle\"></button>");
 	
 	    } else {
 
@@ -453,7 +460,13 @@ string_t* renderCtrlHTMLForm(string_t* no_use, int port)
 	    
             stringAppend(page, "\"> <img src=\"");
             stringAppend(page, icon);
-            stringAppend(page, ".png\" border=\"0\" alt=\"\" style=\"vertical-align: middle\"></button>");
+            stringAppend(page, ".png\" border=\"0\" alt=\"");
+            if (hint && strlen(hint) > 0) {
+                stringAppend(page, hint);
+                stringAppend(page, "\" title=\"");
+                stringAppend(page, hint);
+            }
+            stringAppend(page, "\" style=\"vertical-align: middle\"></button>");
 
         }
 
