@@ -2,11 +2,11 @@
 // anyRemote
 // a wi-fi or bluetooth remote for your PC.
 //
-// Copyright (C) 2006-2013 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2016 Mikhail Fedotov <anyremote@mail.ru>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
+// the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -16,7 +16,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 //
 
 #include <stdio.h>
@@ -75,7 +75,7 @@ mode* getCurrentMode()
 
 void setCurrentMode(mode* m)
 {
-    //DEBUG2("setCurrentMode() %s",(m ? m->name : "NULL"));
+    //DEBUG2("[EX]: setCurrentMode() %s",(m ? m->name : "NULL"));
     currentMode = m;
 }
 
@@ -91,7 +91,7 @@ mode* findMode(const char *name)
         mp = (mode*) mp->next;
     }
     //if (mp) {
-    //	DEBUG2("findMode() %s = %s",name,mp->name->str);
+    //	DEBUG2("[EX]: findMode() %s = %s",name,mp->name->str);
     //}
     return mp;
 }
@@ -121,18 +121,18 @@ mode* addMode(const char *name, const char *parent)
 void switchMode(const char *modeName)
 {
     if (modeName ==  NULL) {
-        logger(L_DBG, "setMode() NULL input");
+        logger(L_DBG, "[EX]: setMode() NULL input");
         return;
     }
-    DEBUG2("setMode() to %s", modeName);
+    DEBUG2("[EX]: setMode() to %s", modeName);
 
     mode *mp = findMode(modeName);
 
     if (mp) {
         currentMode = mp;
-        DEBUG2("setMode() new mode was set to %s", mp->name->str);
+        DEBUG2("[EX]: setMode() new mode was set to %s", mp->name->str);
     } else {
-        logger(L_DBG, "setMode() new mode did not found");
+        logger(L_DBG, "[EX]: setMode() new mode did not found");
     }
 
     return;
@@ -182,7 +182,7 @@ void freeInternalMode()
 //
 void freeModes(mode* fmodes)
 {
-    //logger(L_DBG, "freeModes()");
+    //logger(L_DBG, "[EX]: freeModes()");
     mode * pmodes = (fmodes ? fmodes : modes);
 
     // Keys
