@@ -285,7 +285,7 @@ typedef struct Tk {
 
 typedef struct Cp {
     char       index[6];
-    char       value[MAXARGLEN];
+    char       value[MAXARGLEN+1];
 } cmdParams;
 
 typedef struct {
