@@ -2,11 +2,11 @@
 // anyRemote
 // a wi-fi or bluetooth remote for your PC.
 //
-// Copyright (C) 2012-2014 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2016 Mikhail Fedotov <anyremote@mail.ru>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
+// the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -16,7 +16,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 //
 
 #include <ctype.h>
@@ -53,6 +53,7 @@
 #include "pr_btspp.h"
 #include "common.h"
 #include "utils.h"
+#include "sys_util.h"
 #include "conf.h"
 #include "lib_wrapper.h"
 #include "dispatcher.h"
@@ -80,10 +81,13 @@ typedef struct _BtsppConnection_ {
 
 #ifdef USE_BLUEZ
 
-void sdpRegister(ConnectInfo* connInfo)
+static boolean_t sdpRegister(ConnectInfo* connInfo)
 {
     _BtsppConnection* cn = (_BtsppConnection*) connInfo->connectionData;
-    if (!cn) return;
+    if (!cn) {
+        return BOOL_NO;
+    }
+    boolean_t ret = BOOL_YES;
     
     uint8_t svc_uuid_int[] = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0xab, 0xcd };
     uint8_t rfcomm_channel = connInfo->port;
@@ -146,8 +150,16 @@ void sdpRegister(ConnectInfo* connInfo)
     // connect to the local SDP server, register the service record,
     // and disconnect
     cn->session = sdp_connect(BDADDR_ANY, BDADDR_LOCAL, SDP_RETRY_IF_BUSY);
-    if ( (!(cn->session && cn->record)) || sdp_record_register(cn->session, cn->record, 0) == -1) {
-        logger(L_ERR, "can not register SDP service");
+    if (!cn->session || !cn->record) {
+        ERROR2("can not connect to SDP server %s (%d)", 
+	        strerror(sdp_get_error(cn->session)), sdp_get_error(cn->session));
+	ret = BOOL_NO;
+    }
+    if (cn->session && cn->record && 
+        sdp_record_register(cn->session, cn->record, 0) == -1) {
+        ERROR2("can not register SDP service %s (%d)", 
+	        strerror(sdp_get_error(cn->session)), sdp_get_error(cn->session));
+	ret = BOOL_NO;
     }
 
     // cleanup
@@ -159,16 +171,19 @@ void sdpRegister(ConnectInfo* connInfo)
     sdp_list_free( access_proto_list, 0 );
     sdp_list_free( svc_class_list, 0 );
     sdp_list_free( profile_list, 0 );
+    
+    return ret;
 }
 #endif
 
 #ifdef USE_BT_FBSD
-
-
-static void sdpRegister(ConnectInfo* connInfo)
+static boolean_t sdpRegister(ConnectInfo* connInfo)
 {
     _BtsppConnection* cn = (_BtsppConnection*) connInfo->connectionData;
-    if (!cn) return;
+    if (!cn) {
+        return BOOL_NO;
+    }
+    boolean_t ret = BOOL_YES;
     
     int channel,service;
     bdaddr_t         bt_addr_any;
@@ -180,20 +195,27 @@ static void sdpRegister(ConnectInfo* connInfo)
     cn->session = sdp_open_local(NULL);
     if (cn->session == NULL) {
         errx(1, "Unable to create local SDP session");
+	ret = BOOL_NO;
     }
-    if (sdp_error(cn->session) != 0)
+    if (sdp_error(cn->session) != 0) {
         errx(1, "Unable to open local SDP session. %s (%d)",
              strerror(sdp_error(cn->session)), sdp_error(cn->session));
+	ret = BOOL_NO;
+    }
     memset(&lan, 0, sizeof(lan));
     lan.server_channel = channel;
 
     memcpy(&bt_addr_any, NG_HCI_BDADDR_ANY, sizeof(bt_addr_any));
+    
     if (sdp_register_service(cn->session, service, &bt_addr_any,
                              (void *)&lan, sizeof(lan), &(cn->record)) != 0) {
         errx(1, "Unable to register LAN service with "
              "local SDP daemon. %s (%d)",
              strerror(sdp_error(cn->session)), sdp_error(cn->session));
+	ret = BOOL_NO;
     }
+    
+    return ret;
 }
 #endif
 
@@ -226,13 +248,14 @@ int btsppFD(ConnectInfo* conn)
     if (!cn) {
         return -1;
     }
-    return (conn->state == PEER_WAIT_ACCEPT ? cn->serverFileDescriptor : cn->fileDescriptor);
+    return (conn->state == PEER_WAIT_ACCEPT || 
+            conn->state == PEER_WAIT_LISTEN ? cn->serverFileDescriptor : cn->fileDescriptor);
 }
 
 static int btsppOpenInternal(ConnectInfo* connInfo)
 {
     #ifdef USE_BLUEZ
-    struct sockaddr_rc bt_addr;
+    struct sockaddr_rc bt_addr = { 0 };
     #endif
     #ifdef USE_BT_FBSD
     struct sockaddr_rfcomm bt_addr;
@@ -242,7 +265,7 @@ static int btsppOpenInternal(ConnectInfo* connInfo)
 
     int addFamily = AF_UNSPEC;
     int proto     = 0;
-    int sz;
+    size_t sz;
     
     if (connInfo->connectionData && ((_BtsppConnection*) connInfo->connectionData)->serverFileDescriptor > 0) {
         logger(L_ERR, "BTSPP socket was already opened");
@@ -263,7 +286,7 @@ static int btsppOpenInternal(ConnectInfo* connInfo)
     cn->session              = NULL;
     cn->record               = NULL;
     
-    addFamily = PF_BLUETOOTH;
+    addFamily = AF_BLUETOOTH;
     proto     = BTPROTO_RFCOMM;
     #endif
     
@@ -287,6 +310,7 @@ static int btsppOpenInternal(ConnectInfo* connInfo)
         cn->serverFileDescriptor = -1;
         return -1;
     }
+    DEBUG2("[DS]: btsppOpenInternal srv descriptor %d", cn->serverFileDescriptor);
 
     int optval = 1;
     setsockopt(cn->serverFileDescriptor, SOL_SOCKET, SO_REUSEADDR, &optval, sizeof(optval));
@@ -301,7 +325,8 @@ static int btsppOpenInternal(ConnectInfo* connInfo)
 
 
     #ifdef USE_BLUEZ
-    memset((void *) &bt_addr, 0, sizeof(bt_addr));
+
+    //memset((void *) &bt_addr, 0, sizeof(bt_addr));
     sz = sizeof(bt_addr);
 
     // bind socket to the specified port of the first available local bluetooth adapter
@@ -309,30 +334,79 @@ static int btsppOpenInternal(ConnectInfo* connInfo)
     bt_addr.rc_bdaddr = *BDADDR_ANY;
     bt_addr.rc_channel = (uint8_t) connInfo->port;
 
+    // try to do the same manually
     //char tmpstring[512];
     //sprintf(tmpstring, "sdptool add --channel=%i SP", connInfo->port);
     //sprintf(tmpstring, "sdptool add --channel=%i SP;sdptool setattr `sdptool search --bdaddr local SP|grep \"Service RecHandle\"|tail -1|cut -f 3 -d \" \"` 0x100 anyRemote", connInfo->port);
     //sprintf(tmpstring, "bash -c \'A=`sdptool search --bdaddr local SP|grep \"Service Name\"|grep anyRemote|wc -l`; if [ \"x$A\" == \"x0\" ]; then sdptool add --channel=%i SP;sdptool setattr `sdptool search --bdaddr local SP|grep \"Service RecHandle\"|tail -1|cut -f 3 -d \" \"` 0x100 anyRemote; fi\'", connInfo->port);
     //system(tmpstring);
+    
+    if (sdpRegister(connInfo) == BOOL_YES) {
+    	sprintf(tmp, "[DS]: registered SP for channel %i", connInfo->port);
+    	logger(L_INF, tmp);
+    } else {
+	
+	size_t sz;
+	char* btDaemon = executeCommandPipe("ps -eo args|grep bluetoothd|grep -v grep", &sz);
+	if (btDaemon) {
+	     if (!strstr(btDaemon,"bluetoothd")) {
+	         ERROR2("[DS]: ERROR: bluetoothd daemon is not started");
+		 writeToFrontEnd("Bluetooth connection will not work. bluetoothd daemon is not started");
+		 printf("ERROR: bluetoothd daemon is not started\n");
+	     } else if (!strstr(btDaemon,"-C")) {
+	         ERROR2("[DS]: It needs to run bluetoothd daemon with -C option");
+		 writeToFrontEnd("Bluetooth connection will not work. It needs to run bluetoothd daemon with -C option");
+	         printf("ERROR: Bluetooth connection will not work. It needs to run bluetoothd daemon with -C option\n");
+             } else {
+ 		 ERROR2("[DS]: Not enough permissions to register SDP service");
+		 writeToFrontEnd("Not enough permissions to register SDP service");
+		 printf("ERROR: Not enough permissions to register SDP service\n");
+	     }
+	} else {
+	     ERROR2("[DS]: ERROR: bluetoothd daemon is not started");
+	     writeToFrontEnd("Bluetooth connection will not work. bluetoothd daemon is not started");
+	     printf("ERROR: bluetoothd daemon is not started\n");
+	}
+	
+	
+	/*     } else {
+	         char* sdp = executeCommandPipe("sdptool search --bdaddr local SP", &sz);
+		 if (sdp) {
+		     if (strstr(sdp,"Permission denied")) {
+		         ERROR2("[DS]: Not enough permissions to run sdptool search command");
+			 writeToFrontEnd("Not enough permissions to run sdptool search command");
+		     } else {
+			 printf("TEST %s", sdp);
+	        	 char* ptrptr = NULL;
+    	        	 char* tok  = strtok_r(sdp,"\\n", &ptrptr); 
 
-    sdpRegister(connInfo);
-    sprintf(tmp, "registered SP for channel %i", connInfo->port);
-    logger(L_INF, tmp);
+			 while (tok) {
+	        	     printf("TEST %s", tok);
+			     tok  = strtok_r(NULL,"\\n", &ptrptr); 
+
+			 }
+		     }
+		 }
+	     }
+	}*/
+    }
+    
     socketaddr=(struct sockaddr *)&bt_addr;
     #endif
 
     #ifdef USE_BT_FBSD
     memset(&bt_addr, 0, sizeof(bt_addr));
+    sz = sizeof(bt_addr);
 
     bt_addr.rfcomm_len = sizeof(bt_addr);
     bt_addr.rfcomm_family = AF_BLUETOOTH;
-    bt_addr.rfcomm_channel =  (uint8_t) connInfo->port;;
-    sdpRegister(connInfo);
-    sprintf(tmp, "registered SP for channel %i", connInfo->port);
-    logger(L_INF, tmp);
+    bt_addr.rfcomm_channel =  (uint8_t) connInfo->port;
+    if (sdpRegister(connInfo) == BOOL_YES) {
+        sprintf(tmp, "registered SP for channel %i", connInfo->port);
+        logger(L_INF, tmp);
+    }
 
     socketaddr=(struct sockaddr *)&bt_addr;
-    sz = sizeof(bt_addr);
     #endif
  
     if (bind(cn->serverFileDescriptor, (struct sockaddr *) socketaddr, sz) < 0) {
@@ -340,6 +414,7 @@ static int btsppOpenInternal(ConnectInfo* connInfo)
         printf("ERROR: on binding %d->%s\n", errno, strerror(errno));
         return -1;
     }
+    
     return 1;
 }
 
@@ -349,11 +424,15 @@ int btsppOpen(ConnectInfo* connInfo)
     DEBUG2("[DS]: btsppOpen %d", connInfo->mode);
     if (connInfo->mode != SERVER_BT) {
         DEBUG2("[DS]: btsppOpen wrong mode");
-     }
-
+    }
     if (btsppOpenInternal(connInfo) < 0) {
         return EXIT_NOK;
     }
+    connInfo->state = PEER_WAIT_LISTEN;
+    
+    // make work with bluez 5.x
+    btsppListen(connInfo);
+    
     return EXIT_OK;
 }
 
@@ -368,9 +447,9 @@ void btsppClose(ConnectInfo* connInfo, int final)
 
     if (cn->fileDescriptor >= 0) {
         if (final) {
-        logger(L_INF, "btsppClose close socket");
+            logger(L_INF, "btsppClose close socket");
         }
-    close(cn->fileDescriptor);
+        close(cn->fileDescriptor);
         cn->fileDescriptor = -1;
     }
     if (cn->serverFileDescriptor >= 0) {
@@ -390,21 +469,37 @@ void btsppClose(ConnectInfo* connInfo, int final)
     connInfo->state = PEER_DISCONNECTED;
 }
 
+void btsppReset(ConnectInfo* conn)
+{
+    _BtsppConnection* cn = (_BtsppConnection*) conn->connectionData;
+    if (cn) {
+        if (cn->fileDescriptor >= 0) {
+            close(cn->fileDescriptor);
+            cn->fileDescriptor = -1;
+        }
+        conn->state = PEER_WAIT_ACCEPT;
+    } else {
+        conn->state = PEER_DISCONNECTED;  // should not happens
+    }
+}
+
 //
 // Setup peer
 //
-int btsppSetup(ConnectInfo* conn)
+int btsppListen(ConnectInfo* conn)
 {
-    logger(L_INF, "[DS]: btsppSetup");
+    logger(L_INF, "[DS]: btsppListen");
     
     _BtsppConnection* cn = (_BtsppConnection*) conn->connectionData;
     if (!cn) {
         return -1;
     }
+    INFO2("[DS]: btsppListen: fd %d", cn->serverFileDescriptor);
     int ret = listen(cn->serverFileDescriptor,0);
     if (ret >= 0) {
         conn->state = PEER_WAIT_ACCEPT;
     }
+    INFO2("[DS]: btsppListen ret=%d",ret);
     return (ret < 0 ? -1 : 1);
 }
 
@@ -419,7 +514,8 @@ int btsppAccept(ConnectInfo* connInfo)
     if (!cn) return -1;
     
     logger(L_INF, "[DS]: BTSPP server mode: Waiting connection");
-    int cnt, sz;
+    int cnt;
+    socklen_t sz;
 
     struct sockaddr* socketaddr = NULL;
 
@@ -441,9 +537,9 @@ int btsppAccept(ConnectInfo* connInfo)
 
     while (stillRun) {
 
-        logger(L_INF, "btsppAccept: accept");
+        INFO2("btsppAccept: fd %d", cn->serverFileDescriptor);
 
-        cn->fileDescriptor = accept(cn->serverFileDescriptor, (struct sockaddr *) socketaddr, (socklen_t *)&sz);
+        cn->fileDescriptor = accept(cn->serverFileDescriptor, (struct sockaddr *) socketaddr, &sz);
 
         if (cn->fileDescriptor < 0 && errno == EAGAIN) {
 
@@ -464,6 +560,7 @@ int btsppAccept(ConnectInfo* connInfo)
             logger(L_ERR, "btsppAccept: on accept");
             return -1;
         }
+	INFO2("[DS]: btsppAccept fd=%d",cn->fileDescriptor);
         
 	char* btAddress = NULL;
         #ifdef USE_BLUEZ
@@ -499,6 +596,7 @@ int btsppAccept(ConnectInfo* connInfo)
 
                 if (ret == EXIT_OK) {    // got it
                    break;
+
                 }
             }
 
@@ -526,8 +624,10 @@ int btsppAccept(ConnectInfo* connInfo)
     
         sprintf(tmp, "btsppAccept: remote BT address is %s", (btAddress ? btAddress : "NULL"));
         setBtAddress(btAddress);
-    
         logger(L_INF, tmp);
+        
+        // force to detect cover size. need to do that before (Connect) or syncPeer() handling
+        getClientSize(connInfo->id, cn->fileDescriptor);  
 
         break;
     }
