@@ -2,11 +2,11 @@
 // anyRemote
 // a wi-fi or bluetooth remote for your PC.
 //
-// Copyright (C) 2012-2014 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2016 Mikhail Fedotov <anyremote@mail.ru>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
+// the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -16,7 +16,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 //
 
 #ifndef _PR_SOCKET_H_
@@ -26,9 +26,11 @@
 
 int  socketFD      (ConnectInfo* conn);
 int  socketOpen    (ConnectInfo* conn);
-int  socketSetup   (ConnectInfo* conn);
+int  socketListen  (ConnectInfo* conn);
+//int  socketSetup   (ConnectInfo* conn);
 int  socketAccept  (ConnectInfo* conn);
 int  socketWrite   (ConnectInfo* conn, const dMessage* msg);
 void socketClose   (ConnectInfo* conn, int final);
+void socketReset   (ConnectInfo* conn);
 
 #endif
