@@ -2,7 +2,7 @@
 // anyRemote
 // a wi-fi or bluetooth remote for your PC.
 //
-// Copyright (C) 2006-2016 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2018 Mikhail Fedotov <anyremote@mail.ru>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -786,7 +786,7 @@ boolean_t processHtmlButtonPress(int tvisits, char* p)
     while (isdigit(*p)) {
         p--;
     }
-    int button = ((++p == '\0') ? -1 : atoi(p)+1);
+    int button = ((*(++p) == '\0') ? -1 : atoi(p)+1);
 
     INFO2("[WS]: (%d) Got button %d", tvisits, button);
     
