@@ -77,9 +77,14 @@ int execNoFork(const char *cmd)
 
 static int execInFork(const char *cmd)
 {
+    if (cmd == NULL) {
+        logger(L_ERR,"[EX]: Nothing to fork!");
+        return -1;
+    }
+
     //DEBUG2("[EX]: execInFork >%s<", cmd);
     int cpid = fork();
-    if( cpid < 0) {
+    if (cpid < 0) {
         logger(L_ERR,"[EX]: Can not fork!");
         return -1;
     }
@@ -101,7 +106,7 @@ static int execInFork(const char *cmd)
     closePort(0);
 
     rc = system(cmd);
-    if(rc!=-1 && WIFEXITED(rc)) {
+    if (rc != -1 && WIFEXITED(rc)) {
         rc = WEXITSTATUS(rc);
     }
     exit(rc);
