@@ -2,11 +2,11 @@
 // anyRemote
 // a wi-fi or bluetooth remote for your PC.
 //
-// Copyright (C) 2006-2014 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2016 Mikhail Fedotov <anyremote@mail.ru>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
+// the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -16,7 +16,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 //
 
 #ifndef _UTILS_H
@@ -56,16 +56,9 @@ void        logger          (int head, const char *str);
 
 void        freeMMessage    (void *mm);
 
-int         isDataNew       (int what, const char *data, int size);
-void        freeCachedData  (void);
-
 int         flushData       (void);
 void        flushOldConf    (void);
 
-void        setCmdFiles     (void);
-char*       getResFile      (void);
-char*       getCmdFile      (void);
-
 int         getUidGid       (char *username, uid_t *uid, gid_t *gid);
 
 void 	    addInternalVars (void);
