@@ -2,11 +2,11 @@
 // anyRemote
 // a wi-fi or bluetooth remote for your PC.
 //
-// Copyright (C) 2006-2014 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2016 Mikhail Fedotov <anyremote@mail.ru>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
+// the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -16,7 +16,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 //
 
 //#define USE_XTEST
@@ -76,20 +76,17 @@ static void fakeKeyProcess(KeyCode fakeKey, int shift)
 {
     DEBUG2("fakeKeyProcess Key=%d Shift=%d Ctrl=%d Alt=%d", fakeKey, shift, modifierCtrl, modifierAlt);
     
-    KeyCode shiftKey;
-    KeyCode altKey;
-    KeyCode ctrlKey;
-    
+    KeyCode shiftKey = XKeysymToKeycode(disp,XK_Shift_L);
+    KeyCode altKey   = XKeysymToKeycode(disp,XK_Alt_L);
+    KeyCode ctrlKey  = XKeysymToKeycode(disp,XK_Control_L);
+   
     if (shift) {
-        shiftKey = XKeysymToKeycode(disp,XK_Shift_L);
         XTestFakeKeyEvent(disp, shiftKey, True, CurrentTime);
     }
     if (modifierCtrl) {
-        ctrlKey = XKeysymToKeycode(disp,XK_Control_L);
         XTestFakeKeyEvent(disp, ctrlKey, True, CurrentTime);
     }
     if (modifierAlt) {
-        altKey = XKeysymToKeycode(disp,XK_Alt_L);
         XTestFakeKeyEvent(disp, altKey, True, CurrentTime);
     }
 
@@ -207,9 +204,21 @@ static KeyCode keysymStr2keycode(Display* disp, const char* keysymStr, int* shif
         i++;
     }
     
-    if(ks == NoSymbol) {
+    if (ks == NoSymbol) {
        ks = XStringToKeysym(keysymStr);
+       
+       if (ks != NoSymbol) {  // ok, got it
+            int i=0;
+            while (ksTable[i].ksStr) {  // now detect shift
+                if(ksTable[i].ks == ks) {
+                    (*shift) = ksTable[i].shift;
+                    break;
+                }
+                i++;
+            }
+        }
     }
+    
     DEBUG2("matched %s %ld %d", keysymStr,ks,(*shift));
     
     if (ks == NoSymbol) {
@@ -224,18 +233,23 @@ static KeyCode keysymStr2keycode(Display* disp, const char* keysymStr, int* shif
     }
     
     // check shifted
-    KeySym ks2 = XKeycodeToKeysym(disp, kk, 0);
-    if (ks2 != NoSymbol) {
-        if (ks2 != ks) {  // possibly shifted
+   
+    //KeySym ks2 = XKeycodeToKeysym(disp, kk, 0); // deprecated
+    int keysyms_per_keycode_return;
+    KeySym *ks2 = XGetKeyboardMapping(disp, kk, 1, &keysyms_per_keycode_return);
+    
+    if (*ks2 != NoSymbol) {
+        if (*ks2 != ks) {  // possibly shifted
             KeySym lower_return;
             KeySym upper_return;
-            XConvertCase(ks2, &lower_return, &upper_return);
+            XConvertCase(*ks2, &lower_return, &upper_return);
             
             if (upper_return == ks) {
                 (*shift) = 1;
             }
         }
     }
+    XFree(ks2);
     
     return kk;
 }
